==> haskell-polyparse-1.13-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-polyparse.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 polyparse
version:              1.13
visibility:           public
id:                   polyparse-1.13-Gx3FCEbJsPYLNiGE772lCg
key:                  polyparse-1.13-Gx3FCEbJsPYLNiGE772lCg
license:              LicenseRef-LGPL
copyright:            (c) 2006-2016 Malcolm Wallace
maintainer:           author
author:               Malcolm Wallace <Malcolm.Wallace@me.com>
homepage:             http://code.haskell.org/~malcolm/polyparse/
synopsis:             A variety of alternative parser combinator libraries.
description:
    This version, 1.13 is a Non-Maintainer Upload (NMU).
    Report issues to the Hackage Trustees issue tracker.

    A variety of alternative parser combinator libraries, including
    the original HuttonMeijer set.  The Poly sets have features like
    good error reporting, arbitrary token type, running state, lazy
    parsing, and so on.  Finally, Text.Parse is a proposed
    replacement for the standard Read class, for better
    deserialisation of Haskell values from Strings.

category:             Text, Parsing
abi:                  053fd75ded2713feb4bdb27e64d86834
exposed:              True
exposed-modules:
    Text.Parse Text.Parse.ByteString
    Text.ParserCombinators.HuttonMeijer
    Text.ParserCombinators.HuttonMeijerWallace
    Text.ParserCombinators.Poly Text.ParserCombinators.Poly.Base
    Text.ParserCombinators.Poly.ByteString
    Text.ParserCombinators.Poly.ByteStringChar
    Text.ParserCombinators.Poly.Lazy Text.ParserCombinators.Poly.Lex
    Text.ParserCombinators.Poly.Parser
    Text.ParserCombinators.Poly.Plain
    Text.ParserCombinators.Poly.Result
    Text.ParserCombinators.Poly.State
    Text.ParserCombinators.Poly.StateLazy
    Text.ParserCombinators.Poly.StateParser
    Text.ParserCombinators.Poly.StateText
    Text.ParserCombinators.Poly.Text

import-dirs:          /usr/lib/ghc-8.8.3/site-local/polyparse-1.13
library-dirs:         /usr/lib/ghc-8.8.3/site-local/polyparse-1.13
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/polyparse-1.13
hs-libraries:         HSpolyparse-1.13-Gx3FCEbJsPYLNiGE772lCg
depends:              base-4.13.0.0 bytestring-0.10.10.0 text-1.2.4.0
haddock-interfaces:   /usr/share/doc/haskell-polyparse/html/polyparse.haddock
haddock-html:         /usr/share/doc/haskell-polyparse/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-polyparse-1.13-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-polyparse.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 polyparse
version:              1.13
visibility:           public
id:                   polyparse-1.13-J7tV8ssDwHMcvlIZWsYud
key:                  polyparse-1.13-J7tV8ssDwHMcvlIZWsYud
license:              LicenseRef-LGPL
copyright:            (c) 2006-2016 Malcolm Wallace
maintainer:           author
author:               Malcolm Wallace <Malcolm.Wallace@me.com>
homepage:             http://code.haskell.org/~malcolm/polyparse/
synopsis:             A variety of alternative parser combinator libraries.
description:
    This version, 1.13 is a Non-Maintainer Upload (NMU).
    Report issues to the Hackage Trustees issue tracker.

    A variety of alternative parser combinator libraries, including
    the original HuttonMeijer set.  The Poly sets have features like
    good error reporting, arbitrary token type, running state, lazy
    parsing, and so on.  Finally, Text.Parse is a proposed
    replacement for the standard Read class, for better
    deserialisation of Haskell values from Strings.

category:             Text, Parsing
abi:                  f68190615109101f3aef5f3f6df02abd
exposed:              True
exposed-modules:
    Text.Parse Text.Parse.ByteString
    Text.ParserCombinators.HuttonMeijer
    Text.ParserCombinators.HuttonMeijerWallace
    Text.ParserCombinators.Poly Text.ParserCombinators.Poly.Base
    Text.ParserCombinators.Poly.ByteString
    Text.ParserCombinators.Poly.ByteStringChar
    Text.ParserCombinators.Poly.Lazy Text.ParserCombinators.Poly.Lex
    Text.ParserCombinators.Poly.Parser
    Text.ParserCombinators.Poly.Plain
    Text.ParserCombinators.Poly.Result
    Text.ParserCombinators.Poly.State
    Text.ParserCombinators.Poly.StateLazy
    Text.ParserCombinators.Poly.StateParser
    Text.ParserCombinators.Poly.StateText
    Text.ParserCombinators.Poly.Text

import-dirs:          /usr/lib/ghc-8.10.1/site-local/polyparse-1.13
library-dirs:         /usr/lib/ghc-8.10.1/site-local/polyparse-1.13
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/polyparse-1.13
hs-libraries:         HSpolyparse-1.13-J7tV8ssDwHMcvlIZWsYud
depends:              base-4.14.0.0 bytestring-0.10.10.0 text-1.2.3.2
haddock-interfaces:   /usr/share/doc/haskell-polyparse/html/polyparse.haddock
haddock-html:         /usr/share/doc/haskell-polyparse/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
